@@ -51,7 +51,7 @@ typedef enum {
 	HTML_TABLE_CELL_HEADING,
 	HTML_TABLE_CELL_HALIGN,
 	HTML_TABLE_CELL_VALIGN,
-	HTML_TABLE_CELL_WIDTH
+	HTML_TABLE_CELL_WIDTH,
 } HTMLTableCellAttrType;
 
 union _HTMLTableCellUndoAttr {
@@ -133,7 +133,7 @@ table_cell_set_bg_color (HTMLEngine *e, HTMLTableCell *cell, GdkColor *c, HTMLUn
 	undo = attr_undo_new (HTML_TABLE_CELL_BGCOLOR);
 	undo->attr.color.color        = cell->bg;
 	undo->attr.color.has_bg_color = cell->have_bg;
-	html_undo_add_action (e->undo, e,
+	html_undo_add_action (e->undo,
 			      html_undo_action_new ("Set cell background color", table_cell_set_bg_color_undo_action,
 						    HTML_UNDO_DATA (undo),
 						    html_cursor_get_position (e->cursor),
@@ -172,7 +172,7 @@ table_cell_set_bg_pixmap (HTMLEngine *e, HTMLTableCell *cell, gchar *url, HTMLUn
 
 	undo = attr_undo_new (HTML_TABLE_CELL_BGPIXMAP);
 	undo->attr.pixmap = cell->have_bgPixmap ? g_strdup (cell->bgPixmap->url) : NULL;
-	html_undo_add_action (e->undo, e,
+	html_undo_add_action (e->undo,
 			      html_undo_action_new ("Set cell background pixmap", table_cell_set_bg_pixmap_undo_action,
 						    HTML_UNDO_DATA (undo),
 						    html_cursor_get_position (e->cursor),
@@ -214,7 +214,7 @@ table_cell_set_halign (HTMLEngine *e, HTMLTableCell *cell, HTMLHAlignType halign
 
 	undo = attr_undo_new (HTML_TABLE_CELL_HALIGN);
 	undo->attr.halign = HTML_CLUE (cell)->halign;
-	html_undo_add_action (e->undo, e,
+	html_undo_add_action (e->undo,
 			      html_undo_action_new ("Set cell horizontal align", table_cell_set_halign_undo_action,
 						    HTML_UNDO_DATA (undo),
 						    html_cursor_get_position (e->cursor),
@@ -252,7 +252,7 @@ table_cell_set_valign (HTMLEngine *e, HTMLTableCell *cell, HTMLVAlignType valign
 
 	undo = attr_undo_new (HTML_TABLE_CELL_VALIGN);
 	undo->attr.valign = HTML_CLUE (cell)->valign;
-	html_undo_add_action (e->undo, e,
+	html_undo_add_action (e->undo,
 			      html_undo_action_new ("Set cell vertical align", table_cell_set_valign_undo_action,
 						    HTML_UNDO_DATA (undo),
 						    html_cursor_get_position (e->cursor),
@@ -291,7 +291,7 @@ table_cell_set_no_wrap (HTMLEngine *e, HTMLTableCell *cell, gboolean no_wrap, HT
 
 		undo = attr_undo_new (HTML_TABLE_CELL_NOWRAP);
 		undo->attr.no_wrap = cell->no_wrap;
-		html_undo_add_action (e->undo, e,
+		html_undo_add_action (e->undo,
 				      html_undo_action_new ("Set cell wrapping", table_cell_set_no_wrap_undo_action,
 							    HTML_UNDO_DATA (undo),
 							    html_cursor_get_position (e->cursor),
@@ -331,7 +331,7 @@ table_cell_set_heading (HTMLEngine *e, HTMLTableCell *cell, gboolean heading, HT
 
 		undo = attr_undo_new (HTML_TABLE_CELL_HEADING);
 		undo->attr.heading = cell->heading;
-		html_undo_add_action (e->undo, e,
+		html_undo_add_action (e->undo,
 				      html_undo_action_new ("Set cell style", table_cell_set_heading_undo_action,
 							    HTML_UNDO_DATA (undo),
 							    html_cursor_get_position (e->cursor),
@@ -374,7 +374,7 @@ table_cell_set_width (HTMLEngine *e, HTMLTableCell *cell, gint width, gboolean p
 		undo = attr_undo_new (HTML_TABLE_CELL_WIDTH);
 		undo->attr.width.width = cell->fixed_width;
 		undo->attr.width.percent = cell->percent_width;
-		html_undo_add_action (e->undo, e,
+		html_undo_add_action (e->undo,
 				      html_undo_action_new ("Set cell style", table_cell_set_width_undo_action,
 							    HTML_UNDO_DATA (undo),
 							    html_cursor_get_position (e->cursor),
@@ -449,9 +449,9 @@ move_cell_rd_undo_free (struct MoveCellRDUndo *undo)
 {
 	gint i;
 
-	for (i = 0; i < undo->rspan*undo->cspan; i++)
-		if (undo->removed[i])
-			html_object_destroy (HTML_OBJECT (undo->removed[i]));
+	for (i = 0; i < undo->rspan*undo->cspan; i ++)
+		if (undo->removed [i])
+			html_object_destroy (HTML_OBJECT (undo->removed [i]));
 	g_free (undo->removed);
 	g_free (undo->moved);
 }
@@ -466,17 +466,17 @@ move_cell_rd (HTMLTable *t, HTMLTableCell *cell, gint rs, gint cs)
 
 	undo = move_cell_rd_undo_new (cell->rspan, cell->cspan);
 	/* printf ("move %dx%d --> %dx%d\n", cell->row, cell->col, cell->row + rs, cell->col + cs); */
-	for (r = cell->row + cell->rspan - 1; r >= cell->row; r--)
-		for (c = cell->col + cell->cspan - 1; c >= cell->col; c--) {
+	for (r = cell->row + cell->rspan - 1; r >= cell->row; r --)
+		for (c = cell->col + cell->cspan - 1; c >= cell->col; c --) {
 			if (r > cell->row + cell->rspan - 1 - rs || c > cell->col + cell->cspan - 1 - cs) {
 				gint nr = rs + r - (rs ? cell->rspan : 0), nc = cs + c - (cs ? cell->cspan : 0);
 
 				/* printf ("exchange: %dx%d <--> %dx%d (%p)\n", rs + r, cs + c, nr, nc, t->cells [rs][nc]); */
-				t->cells[nr][nc] = t->cells[rs + r][cs + c];
-				if (t->cells[nr][nc]) {
-					struct Move *move = &undo->moved[(r - cell->row)*cell->cspan + c - cell->col];
+				t->cells [nr][nc] = t->cells [rs + r][cs + c];
+				if (t->cells [nr][nc]) {
+					struct Move *move = &undo->moved [(r - cell->row)*cell->cspan + c - cell->col];
 
-					html_table_cell_set_position (t->cells[nr][nc], nr, nc);
+					html_table_cell_set_position (t->cells [nr][nc], nr, nc);
 					move->rs = rs + r;
 					move->cs = cs + c;
 					move->rt = nr;
@@ -486,16 +486,16 @@ move_cell_rd (HTMLTable *t, HTMLTableCell *cell, gint rs, gint cs)
 				}
 			} else {
 				if (r >= cell->row + rs && c >= cell->col + cs) {
-					if (t->cells[rs + r][cs + c] && t->cells[rs + r][cs + c]->col == cs + c && t->cells[rs + r][cs + c]->row == rs + r) {
+					if (t->cells [rs + r][cs + c] && t->cells [rs + r][cs + c]->col == cs + c && t->cells [rs + r][cs + c]->row == rs + r) {
 						/* printf ("move destroy: %dx%d\n", rs + r, cs + c); */
 						/* html_object_destroy (HTML_OBJECT (t->cells [rs + r][cs + c])); */
 						/* printf ("removed: %dx%d (%d, %d)\n", rs + r, cs + c, r - cell->row, c - cell->col); */
-						undo->removed[(r - cell->row)*cell->cspan + c - cell->col] = t->cells[r][c];
+						undo->removed [(r - cell->row)*cell->cspan + c - cell->col] = t->cells [r][c];
 					}
-					t->cells[r][c] = NULL;
+					t->cells [r][c] = NULL;
 				}
 			}
-			t->cells[rs + r][cs + c] = cell;
+			t->cells [rs + r][cs + c] = cell;
 			/* printf ("cell %dx%d <--\n", rs + r, cs + c); */
 		}
 	/* printf ("set  %dx%d --> %dx%d\n", cell->row, cell->col, cell->row + rs, cell->col + cs); */
@@ -545,26 +545,26 @@ expand_undo_data_new (gint span, GSList *slist)
 static void
 move_cell_rd_undo (HTMLTable *table, struct MoveCellRDUndo *undo)
 {
-	HTMLTableCell *cell = table->cells[undo->move.rt][undo->move.ct];
+	HTMLTableCell *cell = table->cells [undo->move.rt][undo->move.ct];
 	gint r, c;
 
-	for (r = 0; r < undo->rspan; r++)
-		for (c = 0; c < undo->cspan; c++)
-			if (undo->moved[r*undo->cspan + c].move) {
-				struct Move *move = &undo->moved[r*undo->cspan + c];
+	for (r = 0; r < undo->rspan; r ++)
+		for (c = 0; c < undo->cspan; c ++)
+			if (undo->moved [r*undo->cspan + c].move) {
+				struct Move *move = &undo->moved [r*undo->cspan + c];
 
 				/* printf ("move back: %dx%d --> %dx%d (%d, %d) %p\n", move->rt, move->ct, move->rs, move->cs, r, c, table->cells [move->rt][move->ct]); */
-				table->cells[move->rs][move->cs] = table->cells[move->rt][move->ct];
-				html_table_cell_set_position (table->cells[move->rs][move->cs], move->rs, move->cs);
-				table->cells[move->rt][move->ct] = NULL;
+				table->cells [move->rs][move->cs] = table->cells [move->rt][move->ct];
+				html_table_cell_set_position (table->cells [move->rs][move->cs], move->rs, move->cs);
+				table->cells [move->rt][move->ct] = NULL;
 			}
 
-	for (r = 0; r < cell->rspan; r++)
-		for (c = 0; c < cell->cspan; c++)
-			table->cells[undo->move.rt + r][undo->move.ct + c] = NULL;
-	for (r = 0; r < cell->rspan; r++)
-		for (c = 0; c < cell->cspan; c++)
-			table->cells[undo->move.rs + r][undo->move.cs + c] = cell;
+	for (r = 0; r < cell->rspan; r ++)
+		for (c = 0; c < cell->cspan; c ++)
+			table->cells [undo->move.rt + r][undo->move.ct + c] = NULL;
+	for (r = 0; r < cell->rspan; r ++)
+		for (c = 0; c < cell->cspan; c ++)
+			table->cells [undo->move.rs + r][undo->move.cs + c] = cell;
 
 	html_table_cell_set_position (cell, undo->move.rs, undo->move.cs);
 }
@@ -584,7 +584,7 @@ expand_cspan_undo_action (HTMLEngine *e, HTMLUndoData *data, HTMLUndoDirection d
 static void
 expand_cspan_setup_undo (HTMLEngine *e, GSList *slist, gint cspan, guint position_before, HTMLUndoDirection dir)
 {
-	html_undo_add_action (e->undo, e,
+	html_undo_add_action (e->undo,
 			      html_undo_action_new ("Expand Column Span", expand_cspan_undo_action,
 						    expand_undo_data_new (cspan, slist), html_cursor_get_position (e->cursor),
 						    position_before),
@@ -600,25 +600,25 @@ expand_cspan (HTMLEngine *e, HTMLTableCell *cell, gint cspan, HTMLUndoDirection
 	gint r, c, *move_rows, max_move, add_cols;
 
 	move_rows = g_new0 (gint, cell->rspan);
-	for (r = cell->row; r < cell->row + cell->rspan; r++)
-		for (c = cell->col + cell->cspan; c < MIN (cell->col + cspan, table->totalCols); c++)
-			if (table->cells[r][c] && !html_clue_is_empty (HTML_CLUE (table->cells[r][c])) && move_rows[r - cell->row] == 0)
-				move_rows[r - cell->row] = cspan - (c - cell->col);
+	for (r = cell->row; r < cell->row + cell->rspan; r ++)
+		for (c = cell->col + cell->cspan; c < MIN (cell->col + cspan, table->totalCols); c ++)
+			if (table->cells [r][c] && !html_clue_is_empty (HTML_CLUE (table->cells [r][c])) && move_rows [r - cell->row] == 0)
+				move_rows [r - cell->row] = cspan - (c - cell->col);
 
 	max_move = 0;
-	for (r = 0; r < cell->rspan; r++)
-		if (move_rows[r] > max_move)
-			max_move = move_rows[r];
+	for (r = 0; r < cell->rspan; r ++)
+		if (move_rows [r] > max_move)
+			max_move = move_rows [r];
 
 	add_cols = MAX (max_move, cspan - (table->totalCols - cell->col));
 	/* printf ("max move: %d add: %d\n", max_move, add_cols); */
-	for (c = 0; c < add_cols; c++)
+	for (c = 0; c < add_cols; c ++)
 		html_table_insert_column (table, e, table->totalCols, NULL, dir);
 
 	if (max_move > 0) {
-		for (c = table->totalCols - max_move - 1; c >= cell->col + cspan - max_move; c--)
-			for (r = cell->row; r < cell->row + cell->rspan; r++) {
-				HTMLTableCell *ccell = table->cells[r][c];
+		for (c = table->totalCols - max_move - 1; c >= cell->col + cspan - max_move; c --)
+			for (r = cell->row; r < cell->row + cell->rspan; r ++) {
+				HTMLTableCell *ccell = table->cells [r][c];
 
 				if (ccell && ccell->col == c) {
 					slist = g_slist_prepend (slist, move_cell_rd (table, ccell, 0, max_move));
@@ -629,9 +629,9 @@ expand_cspan (HTMLEngine *e, HTMLTableCell *cell, gint cspan, HTMLUndoDirection
 
 	expand_cspan_setup_undo (e, slist, cell->cspan, position_before, dir);
 	cell->cspan = cspan;
-	for (r = cell->row; r < cell->row + cell->rspan; r++)
-		for (c = cell->col; c < cell->col + cell->cspan; c++)
-			table->cells[r][c] = cell;
+	for (r = cell->row; r < cell->row + cell->rspan; r ++)
+		for (c = cell->col; c < cell->col + cell->cspan; c ++)
+			table->cells [r][c] = cell;
 
 	html_object_change_set (HTML_OBJECT (cell), HTML_CHANGE_ALL);
 }
@@ -666,7 +666,7 @@ collapse_cspan_undo_action (HTMLEngine *e, HTMLUndoData *data, HTMLUndoDirection
 static void
 collapse_cspan_setup_undo (HTMLEngine *e, gint cspan, guint position_before, HTMLUndoDirection dir)
 {
-	html_undo_add_action (e->undo, e,
+	html_undo_add_action (e->undo,
 			      html_undo_action_new ("Collapse Column Span", collapse_cspan_undo_action,
 						    collapse_undo_data_new (cspan), html_cursor_get_position (e->cursor),
 						    position_before),
@@ -681,11 +681,11 @@ collapse_cspan (HTMLEngine *e, HTMLTableCell *cell, gint cspan, HTMLUndoDirectio
 	gint r, c;
 
 	table = HTML_TABLE (HTML_OBJECT (cell)->parent);
-	for (c = cell->col + cspan; c < cell->col + cell->cspan; c++)
-		for (r = cell->row; r < cell->row + cell->rspan; r++) {
-			table->cells[r][c] = NULL;
+	for (c = cell->col + cspan; c < cell->col + cell->cspan; c ++)
+		for (r = cell->row; r < cell->row + cell->rspan; r ++) {
+			table->cells [r][c] = NULL;
 			html_table_set_cell (table, r, c, html_engine_new_cell (e, table));
-			html_table_cell_set_position (table->cells[r][c], r, c);
+			html_table_cell_set_position (table->cells [r][c], r, c);
 		}
 
 	collapse_cspan_setup_undo (e, cell->cspan, position_before, dir);
@@ -719,15 +719,15 @@ calc_rspan_max_move (HTMLTableCell *cell, gint rspan)
 	gint r, c, *move_cols, max_move;
 
 	move_cols = g_new0 (gint, cell->cspan);
-	for (c = cell->col; c < cell->col + cell->cspan; c++)
-		for (r = cell->row + cell->rspan; r < MIN (cell->row + rspan, table->totalRows); r++)
-			if (table->cells[r][c] && !html_clue_is_empty (HTML_CLUE (table->cells[r][c])) && move_cols[c - cell->col] == 0)
-				move_cols[c - cell->col] = rspan - (r - cell->row);
+	for (c = cell->col; c < cell->col + cell->cspan; c ++)
+		for (r = cell->row + cell->rspan; r < MIN (cell->row + rspan, table->totalRows); r ++)
+			if (table->cells [r][c] && !html_clue_is_empty (HTML_CLUE (table->cells [r][c])) && move_cols [c - cell->col] == 0)
+				move_cols [c - cell->col] = rspan - (r - cell->row);
 
 	max_move = 0;
-	for (c = 0; c < cell->cspan; c++)
-		if (move_cols[c] > max_move)
-			max_move = move_cols[c];
+	for (c = 0; c < cell->cspan; c ++)
+		if (move_cols [c] > max_move)
+			max_move = move_cols [c];
 	g_free (move_cols);
 
 	return max_move;
@@ -743,13 +743,13 @@ expand_rspan (HTMLEngine *e, HTMLTableCell *cell, gint rspan, HTMLUndoDirection
 	max_move = calc_rspan_max_move (cell, rspan);
 	add_rows = MAX (max_move, rspan - (table->totalRows - cell->row));
 	/* printf ("max move: %d add: %d\n", max_move, add_rows); */
-	for (r = 0; r < add_rows; r++)
+	for (r = 0; r < add_rows; r ++)
 		html_table_insert_row (table, e, table->totalRows, NULL, dir);
 
 	if (max_move > 0) {
-		for (r = table->totalRows - max_move - 1; r >= cell->row + rspan - max_move; r--)
-			for (c = cell->col; c < cell->col + cell->cspan; c++) {
-				HTMLTableCell *ccell = table->cells[r][c];
+		for (r = table->totalRows - max_move - 1; r >= cell->row + rspan - max_move; r --)
+			for (c = cell->col; c < cell->col + cell->cspan; c ++) {
+				HTMLTableCell *ccell = table->cells [r][c];
 
 				if (ccell && ccell->row == r) {
 					slist = g_slist_prepend (slist, move_cell_rd (table, ccell, max_move, 0));
@@ -759,9 +759,9 @@ expand_rspan (HTMLEngine *e, HTMLTableCell *cell, gint rspan, HTMLUndoDirection
 	}
 
 	cell->rspan = rspan;
-	for (r = cell->row; r < cell->row + cell->rspan; r++)
-		for (c = cell->col; c < cell->col + cell->cspan; c++)
-			table->cells[r][c] = cell;
+	for (r = cell->row; r < cell->row + cell->rspan; r ++)
+		for (c = cell->col; c < cell->col + cell->cspan; c ++)
+			table->cells [r][c] = cell;
 
 	html_object_change_set (HTML_OBJECT (cell), HTML_CHANGE_ALL);
 }
@@ -777,7 +777,7 @@ collapse_rspan_undo_action (HTMLEngine *e, HTMLUndoData *data, HTMLUndoDirection
 static void
 collapse_rspan_setup_undo (HTMLEngine *e, gint rspan, guint position_before, HTMLUndoDirection dir)
 {
-	html_undo_add_action (e->undo, e,
+	html_undo_add_action (e->undo,
 			      html_undo_action_new ("Collapse Row Span", collapse_rspan_undo_action,
 						    collapse_undo_data_new (rspan), html_cursor_get_position (e->cursor),
 						    position_before),
@@ -792,11 +792,11 @@ collapse_rspan (HTMLEngine *e, HTMLTableCell *cell, gint rspan, HTMLUndoDirectio
 	gint r, c;
 
 	table = HTML_TABLE (HTML_OBJECT (cell)->parent);
-	for (r = cell->row + rspan; r < cell->row + cell->rspan; r++)
-		for (c = cell->col; c < cell->col + cell->cspan; c++) {
-			table->cells[r][c] = NULL;
+	for (r = cell->row + rspan; r < cell->row + cell->rspan; r ++)
+		for (c = cell->col; c < cell->col + cell->cspan; c ++) {
+			table->cells [r][c] = NULL;
 			html_table_set_cell (table, r, c, html_engine_new_cell (e, table));
-			html_table_cell_set_position (table->cells[r][c], r, c);
+			html_table_cell_set_position (table->cells [r][c], r, c);
 		}
 
 	collapse_rspan_setup_undo (e, cell->rspan, position_before, dir);
