@@ -18,29 +18,29 @@
 #include "htmltext.h"
 
 typedef struct {
-	const gchar *name;
-	gint (*test_function) (GtkHTML *html);
+	char *name;
+	int (*test_function) (GtkHTML *html);
 } Test;
 
-static gint test_cursor_beol (GtkHTML *html);
-static gint test_cursor_beol_rtl (GtkHTML *html);
-static gint test_cursor_left_right_on_items_boundaries (GtkHTML *html);
-static gint test_cursor_left_right_on_lines_boundaries (GtkHTML *html);
-static gint test_cursor_left_right_on_lines_boundaries_rtl (GtkHTML *html);
-static gint test_cursor_left_right_on_lines_boundaries_wo_white (GtkHTML *html);
-static gint test_cursor_around_containers (GtkHTML *html);
-static gint test_cursor_around_image (GtkHTML *html);
-static gint test_cursor_around_anchors (GtkHTML *html);
+static int test_cursor_beol (GtkHTML *html);
+static int test_cursor_beol_rtl (GtkHTML *html);
+static int test_cursor_left_right_on_items_boundaries (GtkHTML *html);
+static int test_cursor_left_right_on_lines_boundaries (GtkHTML *html);
+static int test_cursor_left_right_on_lines_boundaries_rtl (GtkHTML *html);
+static int test_cursor_left_right_on_lines_boundaries_wo_white (GtkHTML *html);
+static int test_cursor_around_containers (GtkHTML *html);
+static int test_cursor_around_image (GtkHTML *html);
+static int test_cursor_around_anchors (GtkHTML *html);
 
-static gint test_quotes_in_div_block (GtkHTML *html);
-static gint test_quotes_in_table (GtkHTML *html);
-static gint test_capitalize_upcase_lowcase_word (GtkHTML *html);
-static gint test_delete_nested_cluevs_and_undo (GtkHTML *html);
-static gint test_insert_nested_cluevs (GtkHTML *html);
-static gint test_indentation_plain_text (GtkHTML *html);
-static gint test_indentation_plain_text_rtl (GtkHTML *html);
-static gint test_table_cell_parsing (GtkHTML *html);
-static gint test_delete_around_table (GtkHTML *html);
+static int test_quotes_in_div_block (GtkHTML *html);
+static int test_quotes_in_table (GtkHTML *html);
+static int test_capitalize_upcase_lowcase_word (GtkHTML *html);
+static int test_delete_nested_cluevs_and_undo (GtkHTML *html);
+static int test_insert_nested_cluevs (GtkHTML *html);
+static int test_indentation_plain_text (GtkHTML *html);
+static int test_indentation_plain_text_rtl (GtkHTML *html);
+static int test_table_cell_parsing (GtkHTML *html);
+static int test_delete_around_table (GtkHTML *html);
 
 static Test tests[] = {
 	{ "cursor movement", NULL },
@@ -66,16 +66,16 @@ static Test tests[] = {
 	{ NULL, NULL }
 };
 
-static void load_editable (GtkHTML *html, const gchar *s)
+static void load_editable (GtkHTML *html, char *s)
 {
 	gtk_html_set_editable (html, FALSE);
 	gtk_html_load_from_string (html, s, -1);
-/*	gtk_html_debug_dump_tree_simple (html->engine->clue, 0); */
+/* 	gtk_html_debug_dump_tree_simple (html->engine->clue, 0); */
 	gtk_html_set_editable (html, TRUE);
 }
 
 static gboolean
-plain_save_receiver (gpointer engine, const gchar *data, gsize len, gpointer user_data)
+plain_save_receiver (gpointer engine, const char *data, size_t len, gpointer user_data)
 {
 	GString *str = (GString *) user_data;
 
@@ -84,11 +84,11 @@ plain_save_receiver (gpointer engine, const gchar *data, gsize len, gpointer use
 	return TRUE;
 }
 
-static gchar *
+static char *
 get_plain (GtkHTML *html)
 {
 	GString *str = g_string_new (NULL);
-	gchar *rv;
+	char *rv;
 
 	html_engine_save_plain (html->engine, plain_save_receiver, str);
 
@@ -98,7 +98,7 @@ get_plain (GtkHTML *html)
 	return rv;
 }
 
-static gint test_delete_nested_cluevs_and_undo (GtkHTML *html)
+static int test_delete_nested_cluevs_and_undo (GtkHTML *html)
 {
 	load_editable (html, "<div>abc</div><div>efg</div>");
 
@@ -130,7 +130,7 @@ static gint test_delete_nested_cluevs_and_undo (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_insert_nested_cluevs (GtkHTML *html)
+static int test_insert_nested_cluevs (GtkHTML *html)
 {
 	load_editable (html, "text");
 
@@ -139,9 +139,9 @@ static gint test_insert_nested_cluevs (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_indentation_plain_text (GtkHTML *html)
+static int test_indentation_plain_text (GtkHTML *html)
 {
-	gchar *str;
+	char *str;
 
 	load_editable (html, "abc<div align=right>abc</div>");
 
@@ -154,9 +154,9 @@ static gint test_indentation_plain_text (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_indentation_plain_text_rtl (GtkHTML *html)
+static int test_indentation_plain_text_rtl (GtkHTML *html)
 {
-	gchar *str;
+	char *str;
 
 	load_editable (html, "שנבגקכעי<div align=left>שנבגקכעי</div>");
 
@@ -169,7 +169,7 @@ static gint test_indentation_plain_text_rtl (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_cursor_around_containers (GtkHTML *html)
+static int test_cursor_around_containers (GtkHTML *html)
 {
 	load_editable (html, "abc<table><tr><td>abc</td></tr></table>");
 
@@ -208,7 +208,7 @@ static gint test_cursor_around_containers (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_cursor_around_image (GtkHTML *html)
+static int test_cursor_around_image (GtkHTML *html)
 {
 	load_editable (html, "<pre>abc <img src=none> abc");
 
@@ -239,7 +239,7 @@ static gint test_cursor_around_image (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_cursor_around_anchors (GtkHTML *html)
+static int test_cursor_around_anchors (GtkHTML *html)
 {
 	load_editable (html, "<pre>a<a name=anchor>b");
 
@@ -306,7 +306,7 @@ static gint test_cursor_around_anchors (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_cursor_left_right_on_items_boundaries (GtkHTML *html)
+static int test_cursor_left_right_on_items_boundaries (GtkHTML *html)
 {
 	load_editable (html, "ab<b>cde</b>ef");
 
@@ -332,6 +332,7 @@ static gint test_cursor_left_right_on_items_boundaries (GtkHTML *html)
 	    || html->engine->cursor->position != 1)
 		return FALSE;
 
+
 	html_cursor_jump_to_position (html->engine->cursor, html->engine, 4);
 	if (html->engine->cursor->position != html->engine->cursor->offset
 	    || html->engine->cursor->position != 4
@@ -359,7 +360,7 @@ static gint test_cursor_left_right_on_items_boundaries (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_cursor_left_right_on_lines_boundaries (GtkHTML *html)
+static int test_cursor_left_right_on_lines_boundaries (GtkHTML *html)
 {
 	load_editable (html, "<pre>first line\nsecond line\nthird line");
 
@@ -390,7 +391,7 @@ static gint test_cursor_left_right_on_lines_boundaries (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_cursor_left_right_on_lines_boundaries_rtl (GtkHTML *html)
+static int test_cursor_left_right_on_lines_boundaries_rtl (GtkHTML *html)
 {
 	load_editable (html, "<pre>أوروبا, برمجيات الحاسوب + انترنيت :\nتصبح عالميا مع يونيكود\nأوروبا, برمجيات الحاسوب + انترنيت :");
 
@@ -421,7 +422,7 @@ static gint test_cursor_left_right_on_lines_boundaries_rtl (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_cursor_left_right_on_lines_boundaries_wo_white (GtkHTML *html)
+static int test_cursor_left_right_on_lines_boundaries_wo_white (GtkHTML *html)
 {
 	load_editable (html, "oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo%next line");
 
@@ -442,7 +443,7 @@ static gint test_cursor_left_right_on_lines_boundaries_wo_white (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_cursor_beol (GtkHTML *html)
+static int test_cursor_beol (GtkHTML *html)
 {
 	load_editable (html, "<pre>simple line\nsecond line\n");
 
@@ -481,7 +482,7 @@ static gint test_cursor_beol (GtkHTML *html)
 	return TRUE;
 }
 
-static gint test_cursor_beol_rtl (GtkHTML *html)
+static int test_cursor_beol_rtl (GtkHTML *html)
 {
 	load_editable (html, "<pre>أوروبا, برمجيات الحاسوب + انترنيت :\nتصبح عالميا مع يونيكود\n");
 
@@ -520,7 +521,7 @@ static gint test_cursor_beol_rtl (GtkHTML *html)
 	return TRUE;
 }
 
-static gint
+static int
 test_quotes_in_div_block (GtkHTML *html)
 {
 	GByteArray *flow_levels;
@@ -542,13 +543,13 @@ test_quotes_in_div_block (GtkHTML *html)
 	flow_levels = HTML_CLUEFLOW (HTML_CLUE (HTML_CLUE (e->clue)->head)->head)->levels;
 
 	/* test if levels are OK */
-	if (!flow_levels || !flow_levels->len == 1 || flow_levels->data[0] != HTML_LIST_TYPE_BLOCKQUOTE_CITE)
+	if (!flow_levels || !flow_levels->len == 1 || flow_levels->data [0] != HTML_LIST_TYPE_BLOCKQUOTE_CITE)
 		return FALSE;
 
 	return TRUE;
 }
 
-static gint
+static int
 test_quotes_in_table (GtkHTML *html)
 {
 	GByteArray *flow_levels;
@@ -569,13 +570,13 @@ test_quotes_in_table (GtkHTML *html)
 	    || !HTML_CLUE (HTML_CLUE (e->clue)->head->next)->head || !HTML_IS_TABLE (HTML_CLUE (HTML_CLUE (e->clue)->head->next)->head))
 		return FALSE;
 
-	table = HTML_TABLE (HTML_CLUE (HTML_CLUE (e->clue)->head->next)->head);
+ 	table = HTML_TABLE (HTML_CLUE (HTML_CLUE (e->clue)->head->next)->head);
 
-	if (table->totalCols != 1 || table->totalRows != 1 || !table->cells[0][0] || !HTML_IS_TABLE_CELL (table->cells[0][0])
-	    || !HTML_CLUE (table->cells[0][0])->head || !HTML_IS_CLUEFLOW (HTML_CLUE (table->cells[0][0])->head))
-		return FALSE;
+ 	if (table->totalCols != 1 || table->totalRows != 1 || !table->cells [0][0] || !HTML_IS_TABLE_CELL (table->cells [0][0])
+	    || !HTML_CLUE (table->cells [0][0])->head || !HTML_IS_CLUEFLOW (HTML_CLUE (table->cells [0][0])->head))
+ 		return FALSE;
 
-	flow_levels = HTML_CLUEFLOW (HTML_CLUE (table->cells[0][0])->head)->levels;
+	flow_levels = HTML_CLUEFLOW (HTML_CLUE (table->cells [0][0])->head)->levels;
 
 	/* test if levels are OK */
 	if (!flow_levels || !flow_levels->len == 0)
@@ -584,7 +585,7 @@ test_quotes_in_table (GtkHTML *html)
 	return TRUE;
 }
 
-static gint
+static int
 test_capitalize_upcase_lowcase_word (GtkHTML *html)
 {
 	HTMLObject *text_object;
@@ -647,7 +648,7 @@ test_capitalize_upcase_lowcase_word (GtkHTML *html)
 	return TRUE;
 }
 
-static gint
+static int
 test_delete_around_table (GtkHTML *html)
 {
 	load_editable (html, "<table><tr><td></td></tr></table><br>abc");
@@ -673,7 +674,7 @@ test_delete_around_table (GtkHTML *html)
 	return TRUE;
 }
 
-static gint
+static int
 test_table_cell_parsing (GtkHTML *html)
 {
 	load_editable (html, "<table><tr><td></td></tr></table>");
@@ -723,11 +724,11 @@ test_table_cell_parsing (GtkHTML *html)
 	return TRUE;
 }
 
-gint main (gint argc, gchar *argv[])
+int main (int argc, char *argv[])
 {
 	GtkWidget *win, *sw, *html_widget;
 	GtkHTML *html;
-	gint i = 0, n_all, n_successful;
+	int i = 0, n_all, n_successful;
 
 	gtk_init (&argc, &argv);
 
@@ -741,26 +742,26 @@ gint main (gint argc, gchar *argv[])
 	gtk_container_add (GTK_CONTAINER (sw), html_widget);
 	gtk_container_add (GTK_CONTAINER (win), sw);
 
-/*	gtk_widget_show_all (win); */
-/*	gtk_widget_show_now (win); */
+/* 	gtk_widget_show_all (win); */
+/* 	gtk_widget_show_now (win); */
 
 	n_all = n_successful = 0;
 
 	fprintf (stderr, "\nGtkHTML test suite\n");
 	fprintf (stderr, "--------------------------------------------------------------------------------\n");
-	for (i = 0; tests[i].name; i++) {
-		gint j, result;
+	for (i = 0; tests [i].name; i ++) {
+		int j, result;
 
-		if (tests[i].test_function) {
+		if (tests [i].test_function) {
 			fprintf (stderr, "  %s ", tests [i].name);
-			for (j = strlen (tests[i].name); j < 69; j++)
+			for (j = strlen (tests [i].name); j < 69; j ++)
 				fputc ('.', stderr);
-			result = (*tests[i].test_function) (html);
+			result = (*tests [i].test_function) (html);
 			fprintf (stderr, " %s\n", result ? "passed" : "failed");
 
-			n_all++;
+			n_all ++;
 			if (result)
-				n_successful++;
+				n_successful ++;
 		} else {
 			fprintf (stderr, "* %s\n", tests [i].name);
 		}
